@@ -1,37 +1,8 @@
-mod display;
-mod methods;
-mod utils;
+pub mod display;
+pub mod methods;
+pub mod utils;
 
-pub use self::utils::*;
 use super::*;
-use crate::{
-    syntax_error,
-    systems::{
-        borders::TailwindBorderStyle,
-        filters::TailwindBrightness,
-        flexbox::{TailWindGrow, TailWindOrder, TailWindShrink, TailwindFlex, TailwindFlexDirection, TailwindFlexWrap},
-    },
-    TailwindBorderCollapse, TailwindBoxDecorationBreak, TailwindBoxSizing, TailwindBreak, TailwindClear, TailwindColumns,
-    TailwindContainer, TailwindContent, TailwindDisplay, TailwindDivideStyle, TailwindFloat, TailwindFontFamily,
-    TailwindFontSize, TailwindFontSmoothing, TailwindFontStyle, TailwindFontVariantNumeric, TailwindFontWeight,
-    TailwindIsolation, TailwindLayoutBreak, TailwindLeading, TailwindListStyle, TailwindListStylePosition, TailwindObjectFit,
-    TailwindObjectPosition, TailwindOutlineStyle, TailwindOverflow, TailwindOverscroll, TailwindPosition,
-    TailwindRingOffsetWidth, TailwindRotate, TailwindScale, TailwindScreenReader, TailwindShadow, TailwindSizing, TailwindSkew,
-    TailwindSpacing, TailwindTextAlignment, TailwindTextColor, TailwindTextDecoration, TailwindTextOverflow,
-    TailwindTextTransform, TailwindTracking, TailwindUnderlineOffset, TailwindVisibility,
-};
-use log::error;
-use std::{
-    fmt::{Display, Formatter, Write},
-    str::FromStr,
-};
-use tailwind_error::nom::{
-    bytes::complete::{take_till, take_till1},
-    character::complete::{alphanumeric1, char, multispace1},
-    combinator::{map_res, recognize},
-    multi::separated_list0,
-    sequence::delimited,
-};
 
 /// `v:v:-a-a-[A]`
 #[derive(Clone)]
@@ -114,6 +85,7 @@ impl AstStyle {
     pub fn get_instance(&self) -> Result<Box<dyn TailwindInstance>> {
         let element = self.view_elements();
         let arbitrary = self.view_arbitrary();
+        let neg = self.negative;
         let instance = match element.as_slice() {
             // Layout System
             ["aspect", rest @ ..] => TailwindAspect::parse(rest, arbitrary)?.boxed(),
@@ -174,10 +146,10 @@ impl AstStyle {
             ["auto", rest @ ..] => todo!(),
             ["gap", rest @ ..] => todo!(),
             ["justify", rest @ ..] => Self::justify_adaptor(rest, arbitrary)?,
-            ["content", rest @ ..] => todo!(),
-            ["items", rest @ ..] => todo!(),
-            ["self", rest @ ..] => todo!(),
-            ["justify", rest @ ..] => Self::place_adaptor(rest, arbitrary)?,
+            ["content", rest @ ..] => Self::content_adaptor(rest, arbitrary)?,
+            ["items", rest @ ..] => TailwindItems::parse(rest, arbitrary)?.boxed(),
+            ["self", rest @ ..] => TailwindSelf::parse(rest, arbitrary)?.boxed(),
+            // justify catched
             // Spacing System
             [p @ ("p" | "pl" | "pr" | "pm" | "pt" | "px" | "py"), rest @ ..] => {
                 TailwindSpacing::parse_padding(rest, p, arbitrary)?.boxed()
@@ -234,8 +206,8 @@ impl AstStyle {
             ["indent", rest @ ..] => todo!(),
             ["align", rest @ ..] => todo!(),
             ["whitespace", rest @ ..] => todo!(),
-            ["break", rest @ ..] => todo!(),
-            ["content", "none"] => TailwindContent::None.boxed(),
+            // break catched
+            // content catched
             // Typography System Extension
             ["prose"] => todo!(),
             // Backgrounds System
@@ -252,36 +224,36 @@ impl AstStyle {
             ["ring", rest @ ..] => Self::ring_adaptor(rest, arbitrary)?,
             // Effects System
             ["shadow", rest @ ..] => Self::shadow_adaptor(rest, arbitrary)?,
-            ["opacity", rest @ ..] => todo!(),
+            ["opacity", rest @ ..] => TailwindOpacity::parse(rest, arbitrary)?.boxed(),
             ["mix", "blend", rest @ ..] => todo!(),
             // Filters System
-            ["blur", rest @ ..] => todo!(),
-            ["brightness", rest @ ..] => TailwindBrightness::parse(rest, arbitrary)?.boxed(),
-            ["contrast", rest @ ..] => todo!(),
+            ["blur", rest @ ..] => TailwindBlur::parse(rest, arbitrary, false)?.boxed(),
+            ["brightness", rest @ ..] => TailwindBrightness::parse(rest, arbitrary, false)?.boxed(),
+            ["contrast", rest @ ..] => TailwindContrast::parse(rest, arbitrary, false)?.boxed(),
             ["drop", "shadow", rest @ ..] => TailwindShadow::parse_drop(rest, arbitrary)?.boxed(),
-            ["grayscale", rest @ ..] => todo!(),
-            ["hue", "rotate", rest @ ..] => todo!(),
-            ["invert", rest @ ..] => todo!(),
-            ["saturate", rest @ ..] => todo!(),
-            ["sepia", rest @ ..] => todo!(),
+            ["grayscale", rest @ ..] => TailwindGrayscale::parse(rest, arbitrary, false)?.boxed(),
+            ["hue", "rotate", rest @ ..] => TailwindHueRotate::parse(rest, arbitrary, false)?.boxed(),
+            ["invert", rest @ ..] => TailwindInvert::parse(rest, arbitrary, false)?.boxed(),
+            ["saturate", rest @ ..] => TailwindSaturate::parse(rest, arbitrary, false)?.boxed(),
+            ["sepia", rest @ ..] => TailwindSepia::parse(rest, arbitrary, false)?.boxed(),
             ["backdrop", rest @ ..] => Self::backdrop_adaptor(rest, arbitrary)?,
             // Tables System
             ["table", rest @ ..] => Self::table_adaptor(rest, arbitrary)?,
             // Transitions System
             ["transition", rest @ ..] => todo!(),
-            ["duration", rest @ ..] => todo!(),
+            ["duration", rest @ ..] => TailwindDuration::parse(rest, arbitrary)?.boxed(),
             ["ease", rest @ ..] => todo!(),
-            ["delay", rest @ ..] => todo!(),
+            ["delay", rest @ ..] => TailwindDelay::parse(rest, arbitrary)?.boxed(),
             ["animate", rest @ ..] => todo!(),
             // Transforms System
-            ["scale", "x", rest @ ..] => TailwindScale::parse(rest, arbitrary, Some(true))?.boxed(),
-            ["scale", "y", rest @ ..] => TailwindScale::parse(rest, arbitrary, Some(false))?.boxed(),
-            ["scale", rest @ ..] => TailwindScale::parse(rest, arbitrary, None)?.boxed(),
-            ["rotate", rest @ ..] => TailwindRotate::parse(rest, arbitrary)?.boxed(),
+            ["scale", "x", rest @ ..] => TailwindScale::parse(rest, arbitrary, Some(true), neg)?.boxed(),
+            ["scale", "y", rest @ ..] => TailwindScale::parse(rest, arbitrary, Some(false), neg)?.boxed(),
+            ["scale", rest @ ..] => TailwindScale::parse(rest, arbitrary, None, neg)?.boxed(),
+            ["rotate", rest @ ..] => TailwindRotate::parse(rest, arbitrary, neg)?.boxed(),
             ["translate", "x", rest @ ..] => todo!(),
             ["translate", "y", rest @ ..] => todo!(),
-            ["skew", "x", rest @ ..] => TailwindSkew::parse(rest, arbitrary, true)?.boxed(),
-            ["skew", "y", rest @ ..] => TailwindSkew::parse(rest, arbitrary, false)?.boxed(),
+            ["skew", "x", rest @ ..] => TailwindSkew::parse(rest, arbitrary, true, neg)?.boxed(),
+            ["skew", "y", rest @ ..] => TailwindSkew::parse(rest, arbitrary, false, neg)?.boxed(),
             ["origin", rest @ ..] => todo!(),
             // Interactivity System
             ["accent", rest @ ..] => todo!(),
@@ -453,6 +425,24 @@ impl AstStyle {
         todo!()
     }
     #[inline]
+    fn content_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
+        let out = match str {
+            // https://tailwindcss.com/docs/align-content
+            ["center"] => TailwindContent::Center.boxed(),
+            ["start"] => TailwindContent::Start.boxed(),
+            ["end"] => TailwindContent::End.boxed(),
+            ["between"] => TailwindContent::Between.boxed(),
+            ["around"] => TailwindContent::Around.boxed(),
+            ["evenly"] => TailwindContent::Evenly.boxed(),
+            // https://tailwindcss.com/docs/content
+            ["none"] => TailwindContentElement::None.boxed(),
+            // https://tailwindcss.com/docs/content#arbitrary-values
+            [] => TailwindContentElement::parse_arbitrary(arbitrary)?.boxed(),
+            _ => return syntax_error!("Unknown content instructions: {}", str.join("-")),
+        };
+        Ok(out)
+    }
+    #[inline]
     fn place_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
         todo!()
     }
