@@ -13,3 +13,11 @@ impl TailwindInstance for TailwindBackgroundColor {
         }
     }
 }
+
+impl Display for TailwindBackgroundBrightness {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        todo!()
+    }
+}
+
+impl TailwindInstance for TailwindBackgroundBrightness {}
